==> libjo_01_19.tar.gz: smarty_dir/templates_c/%%6A^6A5^6A537DD8%%login.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-19 14:05:33
         compiled from login.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">
	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div id="content">
	<div id="pan">

	</div> 
	<div id="center_main">
	<div id="login">

	<?php if ($_GET['type'] == rental): ?>
	<p> 本を借りるにはログインする必要があります </p>
	<?php endif; ?>
				<p> 
					会員登録をされていない方は<a href="entry.php">こちら</a>で登録してください
				</p>

		
        <form method="post">
        <p>ログイン認証 </p>
        <?php if ($this->_tpl_vars['loginerr'] == true): ?>
	<?php echo $this->_tpl_vars['loginerr']; ?>

	<?php endif; ?>
        <ul>
            <li><span>USERNAME</span>:</li>
            <li><input type="text" name="id" value="" /></li>
        </ul>
 <br />
 <ul>
            <li>PASSWORD:</li>
            <li><input type="password" class="text" name="pass" /></li>
        </ul>
 <br />
        <ul>

            <li><input value="ログイン" type="submit" /></li>
        </ul>

        <input type="hidden"  name="continue" value="<?php echo $_GET['continue']; ?>
" />
        </form>
   




			</div> 			<?php if ($_GET['type'] == 'rental'): ?> 			<input type="hidden" name="flag" value="rental">
			<?php else: ?>
			<input type="hidden" name="flag" value="on">
			<?php endif; ?>		
					<div id="login_form">
					</form>

		
				</div> 			</div>		</div> <?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

</body>
</html>

==> libjo_01_26.tar.gz: smarty_dir/templates_c/%%6A^6A5^6A537DD8%%login.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-25 17:29:00
         compiled from login.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">
	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div id="content">
	<div id="pan">

	</div> 
	<div id="center_main">
	<div id="login">

	<?php if ($_GET['type'] == rental): ?>
	<p> 本を借りるにはログインする必要があります </p>
	<?php endif; ?>
				<p> 
					会員登録をされていない方は<a href="entry.php">こちら</a>で登録してください
				</p>

		
        <form method="post">
        <p>ログイン認証 </p>
        <?php if ($this->_tpl_vars['loginerr'] == true): ?>
	<?php echo $this->_tpl_vars['loginerr']; ?>

	<?php endif; ?>
        <ul>
            <li><span>USERNAME</span>:</li>
            <li><input type="text" name="id" value="" /></li>
        </ul>
 <br />
 <ul>
            <li>PASSWORD:</li>
            <li><input type="password" class="text" name="pass" /></li>
        </ul>
 <br />
        <ul>

            <li><input value="ログイン" type="submit" /></li>
        </ul>

        <input type="hidden"  name="continue" value="<?php echo $_GET['continue']; ?>
" />
        </form>
   




			</div> 
		
			</div>		</div> <?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

</body>
</html>
